OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "شسیب",
    "Unknown filetype" : "د فایل ډول نامعلوم دی",
    "Invalid image" : "انځور سم نه دی",
    "Files" : "فایلونه",
    "Apps" : "اپلېکشنونه",
    "Settings" : "سمونې",
    "Accounts" : "Accounts",
    "Storage is temporarily not available" : "ذخیره د لنډې مودې لپاره نشته",
    "Images" : "سیبشسیب"
},
"nplurals=2; plural=(n != 1);");
